# PyMyGekko

Python Library to access the myGEKKO Query API. This project is a work in progress. No guarantee to work until 1.0.0

[![PyPI - Version](https://img.shields.io/pypi/v/pymygekko.svg)](https://pypi.org/project/pymygekko)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pymygekko.svg)](https://pypi.org/project/pymygekko)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install pymygekko
```

## License

`pymygekko` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
